#!/usr/bin/env python
from setuptools import setup    
setup(name='abstractalgorithms',
      version='0.1',
      description='Reference implementations of useful algos',
      author='madgen',
      author_email='madgencontent@gmail.com',
      url='https://github.com/madgen-content/abstractalgorithms',
      packages=['abstractalgorithms']
     )